@@ -25,8 +25,8 @@ class DeleteEpnInstanceRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'DeleteEpnInstance','ens')
 		self.set_method('POST')
 
-	def get_EPNInstanceId(self):
+	def get_EPNInstanceId(self): # String
 		return self.get_query_params().get('EPNInstanceId')
 
-	def set_EPNInstanceId(self,EPNInstanceId):
-		self.add_query_param('EPNInstanceId',EPNInstanceId)
\ No newline at end of file
+	def set_EPNInstanceId(self, EPNInstanceId):  # String
+		self.add_query_param('EPNInstanceId', EPNInstanceId)
