@@ -25,14 +25,13 @@ class DescribeApplicationResourceSummaryRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'DescribeApplicationResourceSummary','ens')
 		self.set_method('POST')
 
-	def get_Level(self):
+	def get_Level(self): # String
 		return self.get_query_params().get('Level')
 
-	def set_Level(self,Level):
-		self.add_query_param('Level',Level)
-
-	def get_ResourceType(self):
+	def set_Level(self, Level):  # String
+		self.add_query_param('Level', Level)
+	def get_ResourceType(self): # String
 		return self.get_query_params().get('ResourceType')
 
-	def set_ResourceType(self,ResourceType):
-		self.add_query_param('ResourceType',ResourceType)
\ No newline at end of file
+	def set_ResourceType(self, ResourceType):  # String
+		self.add_query_param('ResourceType', ResourceType)
